@@ -13,7 +13,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseAdminWidgetContainer.php 2258 2009-08-27 04:05:32Z fishbone $
+ * @version    SVN: $Id: baseAdminWidgetContainer.php 2290 2009-09-09 05:36:34Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -108,7 +108,7 @@ class BaseAdminWidgetContainer extends BaseWidgetContainer
 				if (empty($relativePath)){			// Magic3のルートURLの場合
 					$destPath = $sslBaseUrl;
 				} else if (strStartsWith($relativePath, '/') || strStartsWith($relativePath, '?')){		// ルートURL配下のとき
-					$destPath = self::_createUrlByRelativePath($sslBaseUrl, $relativePath, $param);
+					$destPath = self::_createAdminUrlByRelativePath($sslBaseUrl, $relativePath, $param);
 				} else {		// ルートURL以外のURLのとき
 					$destPath = $path;
 				}
@@ -131,7 +131,7 @@ class BaseAdminWidgetContainer extends BaseWidgetContainer
 	 * @param string,array $param		URLに付加するパラメータ
 	 * @return string				作成したURLパラメータ
 	 */
-	function _createUrlByRelativePath($sslBaseUrl, $path, $param = '')
+	function _createAdminUrlByRelativePath($sslBaseUrl, $path, $param = '')
 	{
 		$destPath = '';
 		
