@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 2218 2009-08-12 04:05:52Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 2326 2009-09-17 05:26:08Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -20,6 +20,7 @@ class BaseFrameContainer extends Core
 {
 	private $_db;	// DB接続オブジェクト
 	const ADMIN_TEMPLATE = '_admin';
+	const M_ADMIN_TEMPLATE = 'm/_admin';	// 携帯用管理画面テンプレート
 	const ERR_MESSAGE_ACCESS_DENY = 'Access denied.';		// ウィジェットアクセスエラーのメッセージ
 	const SITE_IN_PUBLIC = 'site_in_public';			// サイト公開状況
 	const SITE_ACCESS_EXCEPTION_IP = 'site_access_exception_ip';		// アクセス制御、例外とするIP
@@ -233,7 +234,6 @@ class BaseFrameContainer extends Core
 			// ob_end_flush()までの出力をバッファリングする
 			if ($convType == -1){// 携帯用サイトの場合は出力エンコーディングを変更
 				$mobileEncoding = $this->gEnv->getMobileEncoding();		// 携帯用エンコーディングを取得
-				//mb_internal_encoding("UTF-8");
 				mb_http_output($mobileEncoding);
 				ob_start("mb_output_handler"); // 出力のバッファリング開始
 			} else {
@@ -567,15 +567,25 @@ class BaseFrameContainer extends Core
 		
 		// テンプレートの設定
 		// DBで設定されている値を取得し、なければ管理用デフォルトテンプレートを使用
-		$curTemplate = $this->_db->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
-		if (empty($curTemplate)) $curTemplate = self::ADMIN_TEMPLATE;// 管理用テンプレート
+		if ($this->gEnv->getIsMobileSite()){		// 携帯用サイトのアクセスの場合
+			$curTemplate = self::M_ADMIN_TEMPLATE;	// 携帯管理画面用テンプレート
+		} else {
+			$curTemplate = $this->_db->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
+			if (empty($curTemplate)) $curTemplate = self::ADMIN_TEMPLATE;// 管理用テンプレート
+		}
 
 		// カレントのテンプレートIDを設定
 		$this->gEnv->setCurrentTemplateId($curTemplate);
 		
 		// ################### バッファリング開始 ######################
 		// ob_end_flush()までの出力をバッファリングする
-		ob_start();
+		if ($this->gEnv->getIsMobileSite()){		// 携帯用サイトのアクセスの場合		
+			$mobileEncoding = $this->gEnv->getMobileEncoding();		// 携帯用エンコーディングを取得
+			mb_http_output($mobileEncoding);
+			ob_start("mb_output_handler"); // 出力のバッファリング開始
+		} else {
+			ob_start();
+		}
 
 		// サブクラスの前処理を実行
 		$this->_preBuffer($request);
