@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemDb.php 2272 2009-08-31 07:01:38Z fishbone $
+ * @version    SVN: $Id: systemDb.php 2316 2009-09-14 11:28:03Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/baseDb.php');
@@ -487,7 +487,7 @@ class SystemDb extends BaseDb
 	 */
 	function getSubPageId($widgetId, $pageId, &$rows, $setId = 0)
 	{	
-		$queryStr  = 'SELECT DISTINCT pd_sub_id, ';
+		$queryStr  = 'SELECT DISTINCT pd_sub_id, pd_config_id, ';
 		$queryStr .=   'CASE pd_sub_id ';
 		$queryStr .=     'WHEN \'\' THEN -1 ';
 		$queryStr .=     'ELSE pg_priority ';
