@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: instanceManager.php 2044 2009-07-04 03:43:55Z fishbone $
+ * @version    SVN: $Id: instanceManager.php 2293 2009-09-09 07:24:14Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -26,7 +26,6 @@ class InstanceManager extends Core
 	private $userInfo;		// ユーザ情報オブジェクト
 	private $addonDir;		// 追加クラスインストールディレクトリ
 	private $addonArray;	// ロード済みの追加クラス
-	private $mobileAgent;	// 携帯判定用オブジェクト
 		
 	/**
 	 * コンストラクタ
@@ -72,16 +71,16 @@ class InstanceManager extends Core
 	 *
 	 * @return object			取得したオブジェクト
 	 */
-	public function getMobileAgent()
+	static public function getMobileAgent()
 	{
 		global $gEnvManager;
+		static $mobileAgent;// 携帯判定用オブジェクト
 		
-		if (!isset($this->mobileAgent)){
-			//require_once($gEnvManager->getLibPath() . '/Net_UserAgent_Mobile-1.0.0RC1/Mobile.php');
+		if (!isset($mobileAgent)){
 			require_once($gEnvManager->getLibPath() . '/Net_UserAgent_Mobile-1.0.0/Net/UserAgent/Mobile.php');
-			$this->mobileAgent = Net_UserAgent_Mobile::singleton();
+			$mobileAgent = Net_UserAgent_Mobile::singleton();
 		}
-		return $this->mobileAgent;
+		return $mobileAgent;
 	}
 	/**
 	 * オブジェクト取得
