@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInputparamWidgetContainer.php 1318 2008-12-05 05:08:25Z fishbone $
+ * @version    SVN: $Id: _installInputparamWidgetContainer.php 2292 2009-09-09 07:19:01Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -74,6 +74,7 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 		}
 		if (!$canUseDB) $this->setMsg(self::MSG_USER_ERR, "DBが使用できません");
 		
+		$dbtype = '';
 		$isConfigured = false;		// 設定ファイルが作成されたかどうか
 		$act = $request->trimValueOf('act');
 		if ($act == ''){
@@ -84,7 +85,6 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 				// DB種別を取得
 				$pos = strpos($dsn, ':');
 				if ($pos === false){
-					$dbtype = '';
 					$pos = -1;
 				} else {
 					$dbtype = trim(substr($dsn, 0, $pos));
@@ -142,13 +142,14 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 					$gConfigManager->setDbConnectUser($dbuser);// 接続ユーザ
 					$gConfigManager->setDbConnectPassword($password);	// パスワード
 					$gConfigManager->setSystemRootUrl($rooturl);		// システムのルートURL
-					$ret = $gConfigManager->updateConfigFile();
+					$ret = $gConfigManager->updateConfigFile($msg);
 			
 					// 完了メッセージを出力
 					if ($ret){
 						$this->setMsg(self::MSG_GUIDANCE, "設定値を更新しました");
 						$isConfigured = true;
 					} else {
+						$this->setMsg(self::MSG_APP_ERR, $msg);
 						$this->setMsg(self::MSG_APP_ERR, "設定値の更新に失敗しました");
 					}
 				} else if ($act == 'testdb'){		// DB接続テスト
