@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 2276 2009-09-02 04:12:51Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 2321 2009-09-16 03:37:51Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -37,15 +37,20 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function _dispatch($request, &$param)
 	{
+		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
+				
 		// システム制御画面を表示するかどうか
-		if ($this->gPage->getSystemHandleMode() > 0){
-			$this->SetMsg(0, "ただいまサイトのメンテナンス中です");
-			$param = 'message';			// メッセージ画面表示
+		if ($this->gPage->getSystemHandleMode() > 0 && $cmd != M3_REQUEST_CMD_LOGIN){				// ログインの場合はログイン処理へ
+			if ($cmd == M3_REQUEST_CMD_PREVIEW){		// プレビュー画面への遷移のとき
+				$param = 'userlogin';			// ユーザログイン画面表示
+			} else {
+				$this->SetMsg(0, "ただいまサイトのメンテナンス中です");
+				$param = 'message';			// メッセージ画面表示
+			}
 			return true;
 		}
 		
 		// 直接実行の場合
-		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
 		if($cmd == M3_REQUEST_CMD_DO_WIDGET){		// ウィジェット単体実行
 			// 管理者権限がなければ実行できない
 			if ($this->gEnv->isSystemAdmin() || $this->gAccess->isValidAdminKey($request)){
@@ -183,6 +188,8 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 	{
 		if ($param == 'message'){		// メッセージ表示のとき
 			return 'message.tmpl.html';
+		} else if ($param == 'userlogin'){		// ユーザログイン画面
+			return 'userlogin.tmpl.html';
 		} else {
 			return 'index.tmpl.html';
 		}
