@@ -8,19 +8,24 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetlistWidgetContainer.php 1284 2008-11-26 06:31:08Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetlistWidgetContainer.php 2235 2009-08-19 02:00:26Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
+//require_once($gEnvManager->getContainerPath()		. '/baseAdminWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 require_once($gEnvManager->getLibPath()				. '/pcl/pclzip.lib.php' );
+require_once($gEnvManager->getCurrentWidgetContainerPath()		. '/admin_mainDef.php');			// 定義クラス
 
-class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
+class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $newWidget = array();		// 新規追加ウィジェット
+	private $widgetTypeArray;		// ウィジェットタイプ
+	private $widgetType;			// 現在のウィジェットタイプ
+	private $showDetail;			// 詳細表示するかどうか
 	private $defaultImageSize = 32;		// ウィジェット画像サイズ
 	const SCRIPT_FILE_EXT = 'js';		// JavaScriptファイル拡張子
 	const CSS_FILE_EXT = 'css';		// cssファイル拡張子
@@ -36,6 +41,10 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 		
 		// DB接続オブジェクト作成
 		$this->db = new admin_mainDb();
+		
+		// ウィジェットタイプメニュー項目
+		$this->widgetTypeArray = array(	array(	'name' => 'PC用',		'value' => '0'),
+										array(	'name' => '携帯用',		'value' => '1'));
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -49,11 +58,7 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 	 */
 	function _setTemplate($request, &$param)
 	{	
-		if ($this->db->canDetailConfig()){		// 詳細設定可能なとき
-			return 'widgetlist.tmpl.html';
-		} else {
-			return 'widgetlist_simple.tmpl.html';
-		}
+		return 'widgetlist.tmpl.html';
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -66,22 +71,25 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gSystemManager;
-		global $gLaunchManager;
-		global $gMessageManager;
-		
 		$act = $request->trimValueOf('act');
 		$selectedItemNo = $request->trimValueOf('no');		// 処理対象の項目番号
 		$serial = $request->trimValueOf('serial');		// シリアルNo
 		$widgetId = $request->trimValueOf('widget');		// 処理対象のウィジェット
+		$this->widgetType = $request->trimValueOf('item_type');// 現在のウィジェットタイプ
+		if ($this->widgetType == '') $this->widgetType = '0';		// デフォルトはPC用ウィジェット
+		$this->showDetail = ($request->trimValueOf('item_show_detail') == 'on') ? 1 : 0;		// 詳細表示するかどうか
 				
 		if ($act == 'readnew'){		// ウィジェット再読み込みのとき
 			$addWidgetCount = 0;
 			// ウィジェット一覧取得
 			if ($this->db->getAllWidgetIdList($rows)){
 				// ウィジェットディレクトリチェック
-				$searchPath = $gEnvManager->getWidgetsPath();
+				if ($this->widgetType == '0'){		// PC用ウィジェット
+					$searchPath = $this->gEnv->getWidgetsPath();
+				} else {		// 携帯用ウィジェット
+					$searchPath = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_MOBILE;
+				}
+				
 				if (is_dir($searchPath)){
 					$dir = dir($searchPath);
 					while (($file = $dir->read()) !== false){
@@ -90,9 +98,16 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 						if (strncmp($file, '.', 1) != 0 && $file != '..' && is_dir($filePath)
 								&& strncmp($file, '_', 1) != 0		// 「_」で始まる名前のディレクトリは読み込まない
 								&& strcmp($file, 'm') != 0){		// 携帯用のディレクトリ「m」は読み込まない
+							// ウィジェットIDを作成
+							if ($this->widgetType == '0'){		// PC用
+								$widgetId = $file;
+							} else {		// 携帯用
+								$widgetId = M3_DIR_NAME_MOBILE . '/' . $file;
+							}
+							
 							// DBに登録されていない場合は登録
 							for ($i = 0; $i < count($rows); $i++){
-								if ($file == $rows[$i]['wd_id']) break;
+								if ($widgetId == $rows[$i]['wd_id']) break;
 							}
 							if ($i == count($rows)){
 								// ディレクトリ内のスクリプト、CSSの状況を取得
@@ -100,11 +115,11 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 								
 								// ウィジェットを登録
 								if ($ret){
-									$this->db->addNewWidget($file, '(名称未設定)', $hasScripts, $hasCss, $hasAdmin);
+									$this->db->addNewWidget($widgetId, $file, intval($this->widgetType), $hasScripts, $hasCss, $hasAdmin);
 								} else {
-									$this->db->addNewWidget($file, '(名称未設定)');
+									$this->db->addNewWidget($widgetId, $file, intval($this->widgetType));
 								}
-								$this->newWidget[] = $file;			// 新規ウィジェットID保存
+								$this->newWidget[] = $widgetId;			// 新規ウィジェットID保存
 								$addWidgetCount++;		// ウィジェット追加
 							}
 						}
@@ -139,24 +154,29 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 			if ($this->db->getWidget($serial, $row)){
 				// ウィジェットディレクトリ取得
 				$widgetId = $row['wd_id'];
-				$widgetPath = $gEnvManager->getWidgetsPath() . '/' . $widgetId;
+				$widgetPath = $this->gEnv->getWidgetsPath() . '/' . $widgetId;
 				
-				// ウィジェットのアンインストール処理
-				$saveWidgetId = $gEnvManager->getCurrentWidgetId();// ウィジェットID保存
-				$gEnvManager->setCurrentWidgetId($widgetId);// ウィジェットID一時設定
-				$gLaunchManager->goInstallWidget(1);		// アンインストール
-				$gEnvManager->setCurrentWidgetId($saveWidgetId);// ウィジェットID戻す
+				// ウィジェットディレクトリの削除権限のチェック
+				if (is_writable($widgetPath) || !is_dir($widgetPath)){		// 削除可能か、すでにディレクトリがないとき
+					// ウィジェットのアンインストール処理
+					$saveWidgetId = $this->gEnv->getCurrentWidgetId();// ウィジェットID保存
+					$this->gEnv->setCurrentWidgetId($widgetId);// ウィジェットID一時設定
+					$this->gLaunch->goInstallWidget(1);		// アンインストール
+					$this->gEnv->setCurrentWidgetId($saveWidgetId);// ウィジェットID戻す
 						
-				// ディレクトリ削除
-				if ((is_dir($widgetPath) && rmDirectory($widgetPath)) || !is_dir($widgetPath)){// 削除成功か、ディレクトリが存在しないとき
-					$ret = $this->db->deleteWidget($serial, $userId);
-					//if ($ret){		// データ更新成功のとき
-						$this->setMsg(self::MSG_GUIDANCE, 'ウィジェットを削除しました');
-					//} else {
-					//	$this->setMsg(self::MSG_APP_ERR, 'ウィジェット削除に失敗しました');
-					//}
+					// ディレクトリ削除
+					if ((is_dir($widgetPath) && rmDirectory($widgetPath)) || !is_dir($widgetPath)){// 削除成功か、ディレクトリが存在しないとき
+						$ret = $this->db->deleteWidget($serial);
+						//if ($ret){		// データ更新成功のとき
+							$this->setMsg(self::MSG_GUIDANCE, 'ウィジェットを削除しました(ウィジェットID：' . $widgetId . ')');
+						//} else {
+						//	$this->setMsg(self::MSG_APP_ERR, 'ウィジェット削除に失敗しました');
+						//}
+					} else {
+						$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリが削除できませんでした(ディレクトリ：' . $widgetPath . ')');
+					}
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリが削除できませんでした');
+					$this->setMsg(self::MSG_APP_ERR, 'ウィジェットのディレクトリの削除権限がありません(ディレクトリ：' . $widgetPath . ')');
 				}
 			} else {
 				$this->setMsg(self::MSG_APP_ERR, '削除対象のウィジェットが見つかりません');
@@ -172,6 +192,8 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 				$pathParts = pathinfo($uploadFilename);
 				$ext = $pathParts['extension'];		// 拡張子
 				$widgetName = basename($uploadFilename, '.' . $ext);		// 拡張子をはずす
+				$widgetId = $widgetName;
+				if ($this->widgetType != '0') $widgetId = M3_DIR_NAME_MOBILE . '/' . $widgetId;// 携帯の場合はIDを修正
 				
 				// ファイル拡張子のチェック
 				if ($ext != 'zip'){
@@ -181,13 +203,13 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 				
 				if ($this->getMsgCount() == 0){		// エラーが発生していないとき
 					if (!$replaceWidget){		// ウィジェット置き換えないとき
-						// 同名のウィジェットがないかチェック
+						// 同じIDのウィジェットがないかチェック
 						if ($this->db->getAllWidgetIdList($rows)){
 							for ($i = 0; $i < count($rows); $i++){
-								if ($widgetName == $rows[$i]['wd_id']) break;
+								if ($widgetId == $rows[$i]['wd_id']) break;
 							}
 							if ($i < count($rows)){
-								$msg = '同名のウィジェットがすでに存在します(ウィジェット名：' . $widgetName . ')';
+								$msg = 'ウィジェットがすでに存在します(ウィジェットID：' . $widgetId . ')';
 								$this->setAppErrorMsg($msg);
 							}
 						}
@@ -195,13 +217,17 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 				}
 				if ($this->getMsgCount() == 0){		// エラーが発生していないとき
 					// ファイルを保存するサーバディレクトリを指定
-					$tmpFile = tempnam($gEnvManager->getWorkDirPath(), M3_SYSTEM_WORK_UPLOAD_FILENAME_HEAD);
+					$tmpFile = tempnam($this->gEnv->getWorkDirPath(), M3_SYSTEM_WORK_UPLOAD_FILENAME_HEAD);
 
 					// アップされたテンポラリファイルを保存ディレクトリにコピー
 					$ret = move_uploaded_file($_FILES['upfile']['tmp_name'], $tmpFile);
 					if ($ret){
 						// 解凍先ディレクトリ
-						$extDir = $gEnvManager->getWidgetsPath();
+						if ($this->widgetType == '0'){		// PC用ウィジェット
+							$extDir = $this->gEnv->getWidgetsPath();
+						} else {		// 携帯用ウィジェット
+							$extDir = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_MOBILE;
+						}
 					
 						// zipファイルを解凍
 						$zipFile = new PclZip($tmpFile);
@@ -212,7 +238,7 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 							// zipファイル名とディレクトリ名が同じであるかチェック
 							$dirName = $widgetName . '/';
 							if (strncmp($zipList[0]['filename'], $dirName, strlen($dirName)) == 0){
-								$widgetPath = $gEnvManager->getWidgetsPath() . '/' . $widgetName;// ウィジェットのディレクトリ
+								$widgetPath = $this->gEnv->getWidgetsPath() . '/' . $widgetId;// ウィジェットのディレクトリ
 								if ($replaceWidget){		// ウィジェット置き換える場合
 									// ディレクトリ削除
 									if ((is_dir($widgetPath) && rmDirectory($widgetPath)) || !is_dir($widgetPath)){// 削除成功か、ディレクトリが存在しないとき
@@ -224,28 +250,37 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 								if ($this->getMsgCount() == 0){		// エラーが発生していないとき					
 									$ret = $zipFile->extract(PCLZIP_OPT_PATH, $extDir);
 									if ($ret){
+										// ウィジェットの初期化状態を取得
+										// ウィジェットが初期化されている場合はデータをそのまま残す→スクリプトを実行しない
+										$initialized = $this->db->isWidgetInitialized($widgetId);
+
 										// ディレクトリ内のスクリプト、CSSの状況を取得
 										$ret = $this->getDirStatus($widgetPath, $hasScripts, $hasCss, $hasAdmin);
 										
 										// ウィジェットを登録
 										if ($ret){
-											$ret = $this->db->addNewWidget($widgetName, $widgetName, $hasScripts, $hasCss, $hasAdmin);
+											$ret = $this->db->addNewWidget($widgetId, $widgetName, intval($this->widgetType), $hasScripts, $hasCss, $hasAdmin);
 										} else {
-											$ret = $this->db->addNewWidget($widgetName, $widgetName);
+											$ret = $this->db->addNewWidget($widgetId, $widgetName, intval($this->widgetType));
 										}
 								
+										if ($initialized) $this->db->updateIsWidgetInitialized($widgetId, true/*初期化済み*/);
+										
 										// ウィジェットのインストール処理
-										$saveWidgetId = $gEnvManager->getCurrentWidgetId();// ウィジェットID保存
-										$gEnvManager->setCurrentWidgetId($widgetName);// ウィジェットID一時設定
-										$gLaunchManager->goInstallWidget(0);		// インストール
-										$gEnvManager->setCurrentWidgetId($saveWidgetId);// ウィジェットID戻す
+										$saveWidgetId = $this->gEnv->getCurrentWidgetId();// ウィジェットID保存
+										$this->gEnv->setCurrentWidgetId($widgetId);// ウィジェットID一時設定
+										$this->gLaunch->goInstallWidget(0);		// インストール
+										$this->gEnv->setCurrentWidgetId($saveWidgetId);// ウィジェットID戻す
 									
+										// インストールが完了したときは初期化済みに設定
+										$this->db->updateIsWidgetInitialized($widgetId, true/*初期化済み*/);
+										
 										// エラーメッセージを取得
-										$this->addMsg($gMessageManager->getErrorMessage(), $gMessageManager->getWarningMessage(), $gMessageManager->getGuidanceMessage());
+										$this->addMsg($this->gMessage->getErrorMessage(), $this->gMessage->getWarningMessage(), $this->gMessage->getGuidanceMessage());
 									
-										$msg = 'ファイルのアップロードが完了しました(ウィジェット名：' . $widgetName . ')';
+										$msg = 'ファイルのアップロードが完了しました(ウィジェットID：' . $widgetId . ')';
 										$this->setGuidanceMsg($msg);
-										$this->newWidget[] = $widgetName;			// 新規ウィジェットID保存
+										$this->newWidget[] = $widgetId;			// 新規ウィジェットID保存
 									} else {
 										$msg = 'ファイルのアップロードに失敗しました(要因: ' . $zipFile->errorName(true) . ')';
 										$this->setAppErrorMsg($msg);
@@ -264,31 +299,50 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 					unlink($tmpFile);
 				}
 			} else {
-				$msg = 'アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります - ' . $gSystemManager->getMaxFileSizeForUpload() . 'バイト)';
+				$msg = 'アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります - ' . $this->gSystem->getMaxFileSizeForUpload() . 'バイト)';
 				$this->setAppErrorMsg($msg);
 			}
 		} else if ($act == 'download'){		// ファイルダウンロードのとき
-			$widgetsDir = $gEnvManager->getWidgetsPath();		// ウィジェットディレクトリ
-			$widgetDir = $widgetsDir . '/' . $widgetId;			// ダウンロードするウィジェットのディレクトリ
-			$downloadFilename = $widgetId . '.zip';		// ダウンロード時のファイル名
-			$tmpFile = tempnam($gEnvManager->getWorkDirPath(), M3_SYSTEM_WORK_DOWNLOAD_FILENAME_HEAD);		// zip処理用一時ファイル
+			if ($this->widgetType == '0'){		// PC用ウィジェット
+				$widgetsDir = $this->gEnv->getWidgetsPath();		// ウィジェットディレクトリ
+				$widgetDir = $widgetsDir . '/' . $widgetId;		// ダウンロードするウィジェットのディレクトリ
+				$downloadFilename = $widgetId . '.zip';				// ダウンロード時のファイル名
+			} else {		// 携帯用ウィジェット
+				$widgetsDir = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_MOBILE;		// ウィジェットディレクトリ
+				$widgetDir = $this->gEnv->getWidgetsPath() . '/' . $widgetId;				// ダウンロードするウィジェットのディレクトリ
+				list($dir, $filename) = explode('/', $widgetId);		// 先頭の「m/」を削除
+				$downloadFilename = $filename . '.zip';					// ダウンロード時のファイル名
+			}
+			$tmpFile = tempnam($this->gEnv->getWorkDirPath(), M3_SYSTEM_WORK_DOWNLOAD_FILENAME_HEAD);		// zip処理用一時ファイル
 			
 			// zip圧縮
 			$zipFile = new PclZip($tmpFile);
 			$ret = $zipFile->create($widgetDir, PCLZIP_OPT_REMOVE_PATH, $widgetsDir);
 			if ($ret){
+				// ページ作成処理中断
+				$this->gPage->abortPage();
+				
 				// ダウンロード処理
+				$ret = $this->gPage->downloadFile($tmpFile, $downloadFilename, true/*実行後ファイル削除*/);
+				
+				/*$fileSize = filesize($tmpFile);
 				ob_end_clean();
-			    header('Content-disposition: attachment; filename=' . $downloadFilename);
-			    header('Content-type: application/octet-stream; name=' . $downloadFilename);
+				header('Cache-Control: public');		// IE6+SSHでダウンロードエラーが出る問題を回避
+				header('Pragma: public');				// IE6+SSHでダウンロードエラーが出る問題を回避
+			    header('Content-Disposition: attachment; filename=' . $downloadFilename);
+				header('Content-Length: ' . $fileSize);
+			    header('Content-Type: application/octet-stream; name=' . $downloadFilename);
 			    $fp = fopen($tmpFile, "r");
-			    echo fread($fp, filesize($tmpFile));
+			    echo fread($fp, $fileSize);
 			    fclose($fp);
-				ob_end_flush();
+				ob_end_flush();*/
 			
 				// テンポラリファイル削除
-				unlink($tmpFile);
-				return;
+				//unlink($tmpFile);
+				
+				// システム強制終了
+				$this->gPage->exitSystem();
+				//return;
 			} else {
 				$msg = 'ファイルのダウンロードに失敗しました(要因: ' . $zipFile->errorName(true) . ')';
 				$this->setAppErrorMsg($msg);
@@ -296,12 +350,36 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 				// テンポラリファイル削除
 				unlink($tmpFile);
 			}
+		} else if ($act == 'changedetail'){		// 詳細表示の変更のとき
+			// 画面設定値を更新
+			$this->gDisp->setAdminConfig(admin_mainDef::CFG_SHOW_WIDGET_DETAIL, strval($this->showDetail));
 		}
-		// インストールディレクトリを設定
-		$this->tmpl->addVar("_widget", "install_dir", $gEnvManager->getWidgetsPath());
+		// 詳細設定状況を再取得
+		$this->showDetail = intval($this->gDisp->getAdminConfig(admin_mainDef::CFG_SHOW_WIDGET_DETAIL));
+		
+		// ウィジェットのタイプごとの処理
+		if ($this->widgetType == '0'){		// PC用ウィジェット
+			$installDir = $this->gEnv->getWidgetsPath();// ウィジェット格納ディレクトリ
+		} else {			// 携帯用ウィジェット
+			$installDir = $this->gEnv->getWidgetsPath() . '/' . M3_DIR_NAME_MOBILE;// ウィジェット格納ディレクトリ
+		}
+
+		// 表示制御
+		if (!empty($this->showDetail)){		// 詳細表示のとき
+			$this->tmpl->setAttribute('show_dir', 'visibility', 'visible');// ディレクトリ表示
+			$this->tmpl->setAttribute('show_list_detail', 'visibility', 'visible');// 一覧を詳細表示
+		}
+		// ウィジェットタイプ選択メニュー作成
+		$this->createWidgetTypeMenu();
 		
 		// ウィジェットリストを取得
-		$this->db->getAllWidgetList(array($this, 'widgetListLoop'));
+		$this->db->getAllWidgetList(intval($this->widgetType), array($this, 'widgetListLoop'));
+		
+		// 画面にデータを埋め込む
+		$checkedStr = '';
+		if (!empty($this->showDetail)) $checkedStr = 'checked';
+		$this->tmpl->addVar("_widget", "show_detail", $checkedStr);		// 詳細表示
+		$this->tmpl->addVar("show_dir", "install_dir", $installDir);// インストールディレクトリを設定
 	}
 	/**
 	 * ウィジェットのディレクトリの状態を取得
@@ -379,6 +457,29 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 		}
 		return $ret;
 	}
+	/**
+	 * タイプ選択メニュー作成
+	 *
+	 * @return なし
+	 */
+	function createWidgetTypeMenu()
+	{
+		for ($i = 0; $i < count($this->widgetTypeArray); $i++){
+			$value = $this->widgetTypeArray[$i]['value'];
+			$name = $this->widgetTypeArray[$i]['name'];
+			
+			$selected = '';
+			if ($value == $this->widgetType) $selected = 'selected';
+			
+			$row = array(
+				'value'    => $value,			// ページID
+				'name'     => $name,			// ページ名
+				'selected' => $selected														// 選択中かどうか
+			);
+			$this->tmpl->addVars('item_type_list', $row);
+			$this->tmpl->parseTemplate('item_type_list', 'a');
+		}
+	}
 	/**
 	 * ウィジェットリスト、取得したデータをテンプレートに設定する
 	 *
@@ -389,7 +490,10 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 	 */
 	function widgetListLoop($index, $fetchedRow, $param)
 	{
-		global $gDesignManager;
+		// 詳細表示の設定
+		if ($this->showDetail){
+			$this->tmpl->addVar('widgetlist', 'widgettype', 'detail');		// 詳細表示
+		}
 		
 		$hasScript = '';
 		if ($fetchedRow['wd_read_scripts']){
@@ -442,8 +546,8 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 			}
 		}
 		// ウィジェットの画像を設定
-		$image = $gDesignManager->getWidgetIconUrl($id, $this->defaultImageSize);
-		$imageTag = '<img class="widget_obj" src="' . $image . '" ';
+		$image = $this->gDesign->getWidgetIconUrl($id, $this->defaultImageSize);
+		$imageTag = '<img class="widget_obj" src="' . $this->getUrl($image) . '" ';
 		$imageTag .= 'width="' . $this->defaultImageSize . '"';
 		$imageTag .= ' height="' . $this->defaultImageSize . '"';
 		$imageTag .= ' />';
