@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: custom_headerWidgetContainer.php 1526 2009-02-27 02:33:43Z fishbone $
+ * @version    SVN: $Id: custom_headerWidgetContainer.php 2223 2009-08-14 08:45:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -138,7 +138,7 @@ class custom_headerWidgetContainer extends BaseWidgetContainer
 			$this->width = 'width: ' . $this->width . ';';
 			$this->height = 'height: ' . $this->height . ';';			
 		} else {
-			$image = '<img src="' . $imageUrl . '" width="' . $this->width . '" height="' . $this->height . '" style="z-index:0" />';
+			$image = '<img src="' . $this->getUrl($imageUrl) . '" width="' . $this->width . '" height="' . $this->height . '" style="z-index:0" />';
 			$this->tmpl->addVar("_widget", "image", $image);		// 画像
 			
 			// CSSの高さ、幅をクリア
