@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 2220 2009-08-12 06:08:37Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 2313 2009-09-13 12:33:26Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_default_contentBaseWidgetContainer.php');
@@ -21,6 +21,8 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	private $db;	// DB接続オブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $serialArray = array();		// 表示されているコンテンツシリアル番号
+	private $selectedItem = array();	// 選択中の項目
+	private $completed;			// データ登録完了かどうか
 	private $_menuId = 'main_menu';				// メインメニューID
 	private $isExistsContent;		// コンテンツ項目が存在するかどうか
 	const INC_INDEX = 1;		// メニュー項目表示順の増加分
@@ -50,12 +52,21 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	 */
 	function _setTemplate($request, &$param)
 	{
+		$filename = '';
 		$task = $request->trimValueOf('task');
-		if ($task == 'content_detail'){		// 詳細画面
-			return 'admin_main_detail.tmpl.html';
-		} else {			// 一覧画面
-			return 'admin_main.tmpl.html';
+		switch ($task){
+			case 'content':		// コンテンツ管理
+			default:
+				$filename = 'admin_main.tmpl.html';
+				break;
+			case 'content_detail':		// 詳細画面
+				$filename = 'admin_main_detail.tmpl.html';
+				break;
+			case 'add_to_menu':		// コンテンツへのリンクをメニュー項目に追加
+				$filename = 'admin_list.tmpl.html';
+				break;
 		}
+		return $filename;
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -64,15 +75,22 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	 *
 	 * @param RequestManager $request		HTTPリクエスト処理クラス
 	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
-	 * @param								なし
+	 * @return								なし
 	 */
 	function _assign($request, &$param)
 	{
 		$task = $request->trimValueOf('task');
-		if ($task == 'content_detail'){	// 詳細画面
-			return $this->createDetail($request);
-		} else {			// 一覧画面
-			return $this->createList($request);
+		switch ($task){
+			case 'content':		// コンテンツ管理
+			default:
+				$this->createList($request);
+				break;
+			case 'content_detail':		// 詳細画面
+				$this->createDetail($request);
+				break;
+			case 'add_to_menu':		// コンテンツへのリンクをメニュー項目に追加
+				$this->createAddToMenu($request);
+				break;
 		}
 	}
 	/**
@@ -88,33 +106,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		$langId = $this->gEnv->getDefaultLanguage();
 		
 		$act = $request->trimValueOf('act');
-		if ($act == 'addtomenu'){			// メニューに項目を追加
-			$contentId = $request->trimValueOf('contentid');		// コンテンツID
-			
-			// このウィジェットがマップされているページサブIDを取得
-			$subPageId = $this->gPage->getPageSubIdByWidget($this->gEnv->getDefaultPageId(), $this->gEnv->getCurrentWidgetId());
-			$sub = '';
-			if (!empty($subPageId)) $sub = 'sub=' . $subPageId . '&';
-			
-			// URLの作成
-			$url = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . '/index.php?' . $sub . 'contentid=' . $contentId;
-
-			// コンテンツ名を取得
-			$menutItemName = '';
-			$ret = $this->db->getContentByContentId($contentId, $langId, $row);
-			if ($ret){
-				// 取得値を設定
-				$menutItemName = $row['cn_name'];		// 名前
-			}
-			
-			// メニュー項目追加
-			$ret = $this->db->addMenuItem($this->_menuId, $langId, $menutItemName, $url, self::INC_INDEX, $userId);
-			if ($ret){
-				$this->setGuidanceMsg('メインメニューに項目を追加しました');
-			} else {
-				$this->setAppErrorMsg('メインメニューの項目追加に失敗しました');
-			}
-		} else if ($act == 'delete'){		// 項目削除の場合
+		if ($act == 'delete'){		// 項目削除の場合
 			$listedItem = explode(',', $request->trimValueOf('seriallist'));
 			$delItems = array();
 			for ($i = 0; $i < count($listedItem); $i++){
@@ -288,6 +280,70 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		// 「戻る」ボタンの表示
 		if ($openby == 'simple') $this->tmpl->setAttribute('cancel_button', 'visibility', 'hidden');		// 詳細画面のみの表示のときは戻るボタンを隠す
 	}
+	/**
+	 * コンテンツへのリンクをメニューに追加するための画面作成
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param								なし
+	 */
+	function createAddToMenu($request)
+	{
+		// ユーザ情報、表示言語
+		$userId = $this->gEnv->getCurrentUserId();
+		$langId = $this->gEnv->getDefaultLanguage();
+
+		$act = $request->trimValueOf('act');
+		$contentId = $request->trimValueOf('contentid');		// コンテンツID
+		$serialList = $request->trimValueOf('seriallist');
+		if (!empty($serialList)){
+			$listedItem = explode(',', $serialList);
+			for ($i = 0; $i < count($listedItem); $i++){
+				// 項目がチェックされているかを取得
+				$itemName = 'item' . $i . '_selected';
+				$itemValue = ($request->trimValueOf($itemName) == 'on') ? 1 : 0;
+				if ($itemValue) $this->selectedItem[] = $listedItem[$i];// チェック項目
+			}
+		}
+		if ($act == 'addtomenu'){			// メニューに項目を追加
+			// このウィジェットがマップされているページサブIDを取得
+			$subPageId = $this->gPage->getPageSubIdByWidget($this->gEnv->getDefaultPageId(), $this->gEnv->getCurrentWidgetId());
+			$sub = '';
+			if (!empty($subPageId)) $sub = 'sub=' . $subPageId . '&';
+			
+			// URLの作成
+			$url = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . '/' . $this->gEnv->getDefaultPageId() . '.php?' . $sub . 'contentid=' . $contentId;
+
+			// コンテンツ名を取得
+			$menutItemName = '';
+			$ret = $this->db->getContentByContentId($contentId, $langId, $row);
+			if ($ret) $menutItemName = $row['cn_name'];		// 名前は取得値を設定
+
+			// メニュー項目追加
+			for ($i = 0; $i < count($this->selectedItem); $i++){
+				$ret = $this->db->addMenuItem($this->selectedItem[$i], $menutItemName, $url);
+				if (!$ret) break;
+			}
+			if ($ret){
+				$this->setGuidanceMsg('メニューにリンクを追加しました');
+				$this->completed = true;			// データ登録完了かどうか
+			} else {
+				$this->setAppErrorMsg('メニューのリンク追加に失敗しました');
+			}
+		}
+		
+		// メニューID選択メニュー作成
+		$this->db->getMenuIdList(array($this, 'menuIdListLoop'));
+		
+		$this->tmpl->addVar("_widget", "content_id", $contentId);// コンテンツID
+		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
+		
+		// 一覧項目がないときは、一覧を表示しない
+		if (!$this->isExistsContent) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');
+		
+		if ($this->completed){// 	データ追加完了のとき
+			$this->tmpl->addVar('_widget', 'add_disabled', 'disabled');// 「追加」ボタン
+		}
+	}
 	/**
 	 * 取得したデータをテンプレートに設定する
 	 *
@@ -336,7 +392,6 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			'id' => $this->convertToDispString($fetchedRow['cn_id']),			// ID
 			'name' => $this->convertToDispString($fetchedRow['cn_name']),		// 名前
 			'lang' => $lang,													// 対応言語
-			'link_str' => $this->convertToDispString($fetchedRow['cn_link_url']),		// リンクURL
 			'view_count' => $totalViewCount,									// 総参照数
 			'update_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 更新者
 			'update_dt' => $this->convertToDispDateTime($fetchedRow['cn_create_dt']),	// 更新日時
@@ -353,5 +408,36 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		$this->isExistsContent = true;		// コンテンツ項目が存在するかどうか
 		return true;
 	}
+	/**
+	 * 取得したデータをテンプレートに設定する
+	 *
+	 * @param int $index			行番号(0～)
+	 * @param array $fetchedRow		フェッチ取得した行
+	 * @param object $param			未使用
+	 * @return bool					true=処理続行の場合、false=処理終了の場合
+	 */
+	function menuIdListLoop($index, $fetchedRow, $param)
+	{
+		$id = $fetchedRow['mn_id'];
+		
+		$checkStr = '';
+		if (in_array($id, $this->selectedItem)) $checkStr = 'checked ';
+		if ($this->completed) $checkStr .= 'disabled ';			// 追加完了のとき
+		
+		$row = array(
+			'index' => $index,													// 項目番号
+			'serial' => $this->convertToDispString($id),			// シリアル番号
+			'id' => $this->convertToDispString($id),			// ID
+			'name' => $this->convertToDispString($fetchedRow['mn_name']),		// 名前
+			'check' => $checkStr		// チェック状態
+		);
+		$this->tmpl->addVars('itemlist', $row);
+		$this->tmpl->parseTemplate('itemlist', 'a');
+		
+		// 表示中項目IDを保存
+		$this->serialArray[] = $id;
+		$this->isExistsContent = true;		// コンテンツ項目が存在するかどうか
+		return true;
+	}
 }
 ?>
