@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentWidgetContainer.php 2220 2009-08-12 06:08:37Z fishbone $
+ * @version    SVN: $Id: default_contentWidgetContainer.php 2296 2009-09-09 10:14:28Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -58,7 +58,13 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 		if ($act == 'search'){
 			return 'search.tmpl.html';
 		} else {
-			return 'main.tmpl.html';
+			// Joomlaテンプレートのバージョンに合わせて出力
+			$this->templateType = $this->gEnv->getCurrentTemplateType();
+			if ($this->templateType == 0){			// Joomla!v1.0のとき
+				return 'main_old.tmpl.html';
+			} else {
+				return 'main.tmpl.html';
+			}
 		}
 	}
 	/**
