@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainMemberWidgetContainer.php 210 2008-03-03 08:36:32Z naoki $
+ * @version    SVN: $Id: admin_ec_mainMemberWidgetContainer.php 2260 2009-08-27 05:59:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -403,7 +403,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 						$url = $gPageManager->createWidgetCmdUrl($gEnvManager->getDefaultPageId(), self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, $loginParam);
 						$mailParam = array();
 						$mailParam['PASSWORD'] = $password;
-						$mailParam['URL']		= $url;		// ログイン用URL
+						$mailParam['URL']		= $this->getUrl($url, true);		// ログイン用URL
 						$ret = $gMailManager->sendFormMail(2/*手動送信*/, $gEnvManager->getCurrentWidgetId(), $toAddress, $fromAddress, '', '', self::SEND_PASSWORD_FORM, $mailParam);// 手動送信
 						
 						// パスワード変更のメッセージ
@@ -584,7 +584,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		// 値を埋め込む
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
 		$this->tmpl->addVar("_widget", "member_type", $this->memberType);
-		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());	// スクリプトパスの設定
+		//$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());	// スクリプトパスの設定
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
