@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainAgreememberWidgetContainer.php 212 2008-03-03 11:36:27Z naoki $
+ * @version    SVN: $Id: ec_mainAgreememberWidgetContainer.php 2264 2009-08-28 06:08:21Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -28,14 +28,12 @@ class ec_mainAgreememberWidgetContainer extends BaseWidgetContainer
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DB接続オブジェクト作成
 		$this->mainDb = new ec_mainDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -62,11 +60,7 @@ class ec_mainAgreememberWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-		global $gTextConvManager;
-		
-		$langId = $gEnvManager->getCurrentLanguage();		// 表示言語を取得
+		$langId = $this->gEnv->getCurrentLanguage();		// 表示言語を取得
 		
 		$act = $request->trimValueOf('act');
 		if ($act == 'agree'){			// 会員規約に同意のとき
@@ -74,8 +68,8 @@ class ec_mainAgreememberWidgetContainer extends BaseWidgetContainer
 			$this->setWidgetSession(self::SES_KEY_AGREE_MEMBER, 1);
 			
 			// 会員登録画面へ遷移
-			$regmemberPage = $gEnvManager->createCurrentPageUrl() . '&task=regmember';
-			$gPageManager->redirect($regmemberPage);
+			$regmemberPage = $this->gEnv->createCurrentPageUrl() . '&task=regmember';
+			$this->gPage->redirect($regmemberPage);
 			return;
 		}
 		// 会員規約を取得
@@ -85,10 +79,11 @@ class ec_mainAgreememberWidgetContainer extends BaseWidgetContainer
 		}
 		
 		// 登録したキーワードを変換
-		$gTextConvManager->convByKeyValue($content, $content, true/*改行コーをbrタグに変換*/);
+		$this->gTextConv->convByKeyValue($content, $content, true/*改行コーをbrタグに変換*/);
 		
+		$this->tmpl->addVar("_widget", "class", $this->gDesign->getDefaultContentHeadClassString());		// コンテンツヘッダ用CSSクラス
 		$this->tmpl->addVar("_widget", "content", $content);		// 会員規約
-		$this->tmpl->addVar("_widget", "cancel_url", $gEnvManager->createCurrentPageUrl());		// キャンセル用URL
+		$this->tmpl->addVar("_widget", "cancel_url", $this->getUrl($this->gEnv->getRootUrl(), true));		// キャンセル用URL(トップページ)
 	}
 }
 ?>
