@@ -8,17 +8,18 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainOrderhistoryWidgetContainer.php 174 2008-01-22 12:06:54Z naoki $
+ * @version    SVN: $Id: ec_mainOrderhistoryWidgetContainer.php 2264 2009-08-28 06:08:21Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+//require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/ec_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath()	. '/ec_mainOrderDb.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/productDb.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainDb.php');
 
-class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
+class ec_mainOrderhistoryWidgetContainer extends ec_mainBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $productDb;	// DB接続オブジェクト
@@ -42,8 +43,6 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
@@ -53,7 +52,7 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 		$this->productDb = new productDb();
 		
 		// 価格計算用オブジェクト取得
-		$this->ecObj = $gInstanceManager->getObject(self::PRICE_OBJ_ID);
+		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -80,12 +79,9 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-		
 		$now = date("Y/m/d H:i:s");	// 現在日時
-		$this->langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
-		$userId = $gEnvManager->getCurrentUserId();		// ログイン中のユーザ
+		$this->langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
+		$userId = $this->gEnv->getCurrentUserId();		// ログイン中のユーザ
 		$this->currency = $this->ecObj->getDefaultCurrency();		// 通貨
 		
 		$this->orderId = $request->trimValueOf('item_order');		// 受注ID
@@ -114,7 +110,7 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 					$orderNo = $row['or_order_no'];		// 注文番号
 					$orderDt	= $row['or_regist_dt'];	// 注文日時
 					$regUserId	= $row['or_user_id'];	// 注文を行ったユーザ
-					if (!empty($orderDt) && $orderDt != $gEnvManager->getInitValueOfTimestamp() && 
+					if (!empty($orderDt) && $orderDt != $this->gEnv->getInitValueOfTimestamp() && 
 							strtotime("-$hour hours") <= strtotime($orderDt)){	// キャンセル有効のとき
 						// 受注キャンセルメール送信
 						// 会員情報を取得
@@ -193,16 +189,19 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 			$this->tmpl->setAttribute('order_history', 'visibility', 'visible');
 			
 			// キャンセル可能なときは、キャンセルボタンを表示
-			if (!empty($orderDt) && $orderDt != $gEnvManager->getInitValueOfTimestamp() && 
+			if (!empty($orderDt) && $orderDt != $this->gEnv->getInitValueOfTimestamp() && 
 					strtotime("-$hour hours") <= strtotime($orderDt)){	// キャンセル有効のとき
 				$this->tmpl->setAttribute('cancel_button', 'visibility', 'visible');
 			}
 		} else {
 			$this->tmpl->addVar("_widget", "message", '注文履歴がありません');
 		}
+		// タイトルのCSSを設定
+		$this->tmpl->addVar("_widget", "class", $this->gDesign->getDefaultContentHeadClassString());		// コンテンツヘッダ用CSSクラス
+		
 		// 遷移先を設定
-		//$this->tmpl->addVar("_widget", "payment_url", $gEnvManager->createCurrentPageUrl() . '&task=payment');		// 支払い方法選択画面
-		//$this->tmpl->addVar("_widget", "delivery_url", $gEnvManager->createCurrentPageUrl() . '&task=delivery');		// 配送先画面
+		//$this->tmpl->addVar("_widget", "payment_url", $this->getUrl($this->gEnv->createCurrentPageUrl() . '&task=payment', true));		// 支払い方法選択画面
+		//$this->tmpl->addVar("_widget", "delivery_url", $this->getUrl($this->gEnv->createCurrentPageUrl() . '&task=delivery', true));		// 配送先画面
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -214,8 +213,6 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 	 */
 	function orderListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['or_id'] == $this->orderId){		// 選択中の受注ID
 			$selected = 'selected';
@@ -243,8 +240,6 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 	 */
 	function orderItemLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		// 行カラーの設定
 		$lineColor = '';
 		if ($index % 2 != 0){
@@ -301,11 +296,12 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 		
 		// 商品詳細へのリンク
 		$url  = '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_FIND_WIDGET;
-		$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId();
-		$url .= '&' . M3_REQUEST_PARAM_FROM . '=' . $gEnvManager->getCurrentWidgetId();		// 送信元
+		//$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
+		$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . self::TARGET_PRODUCT_WIDGET;		// 商品表示ウィジェットを指定
+		$url .= '&' . M3_REQUEST_PARAM_FROM . '=' . $this->gEnv->getCurrentWidgetId();		// 送信元
 		$url .= '&' . M3_REQUEST_PARAM_OPERATION_TODO . '=' . urlencode('product=' . $fetchedRow['si_product_id']);
 			
-		$nameLink = '<a href="' . $url . '">' . $name . '</a>';
+		$nameLink = '<a href="' . $this->getUrl($url, true) . '">' . $name . '</a>';
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
@@ -364,9 +360,6 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 	function sendMailToBackoffice($mailType, $orderNo, $memberNo, $email, $memberName, $delivName, $nameKana, $zipcode, $address1, $address2, $phone, 
 									$demandDt, $demandTime, $delivMethod, $payMethod, $note, $orderDetail)
 	{	
-		global $gEnvManager;
-		global $gMailManager;
-	
 		// メール連携許可のときはメールを送信
 		if ($this->mainDb->getConfig(self::USE_EMAIL_TO_BACKOFFICE) == '1'){
 			$fromAddress = $this->mainDb->getConfig(self::MAIL_FROM_ORDER_PRODUCT);	// 連携メール送信元
@@ -402,7 +395,7 @@ class ec_mainOrderhistoryWidgetContainer extends BaseWidgetContainer
 			$mailParam['DELIV_METHOD'] = $delivMethod;	// 配送方法
 			$mailParam['PAY_METHOD'] = $payMethod;	// 決済方法
 			$mailParam['NOTE'] = $note;	// 備考
-			$ret = $gMailManager->sendFormMail(1/*自動送信*/, $gEnvManager->getCurrentWidgetId(), $toAddress, $fromAddress, ''/*返信先*/,
+			$ret = $this->gMail->sendFormMail(1/*自動送信*/, $this->gEnv->getCurrentWidgetId(), $toAddress, $fromAddress, ''/*返信先*/,
 												$subject/*件名*/, self::ORDER_PRODUCT_TO_BACKOFFICE_FORM, $mailParam);// 自動送信
 		}
 	}
