@@ -10,17 +10,19 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainWidgetContainer.php 1670 2009-03-30 07:21:56Z fishbone $
+ * @version    SVN: $Id: ec_mainWidgetContainer.php 2264 2009-08-28 06:08:21Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+//require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/ec_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/ec_mainDb.php');
 
-class ec_mainWidgetContainer extends BaseWidgetContainer
+class ec_mainWidgetContainer extends ec_mainBaseWidgetContainer
 {
 	private $mainDb;	// DB接続オブジェクト
 	const SES_KEY_AGREE_MEMBER = 'agree_member';		// 会員規約に同意したかどうかのセッションキー
 	const CF_PERMIT_NON_MEMBER_ORDER = 'permit_non_member_order';			// 非会員の購入許可
+	const DEFAULT_TOP_PAGE = 'order';		// デフォルトのトップページ
 	
 	/**
 	 * コンストラクタ
@@ -46,23 +48,23 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 	{
 		// 実行処理を決定
 		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
-		if (empty($task)) $task = 'product';
+		if (empty($task)) $task = self::DEFAULT_TOP_PAGE;
 
 		// ##### アクセス制御 #####
 		$canNonMemberOrder = $this->mainDb->getConfig(self::CF_PERMIT_NON_MEMBER_ORDER);
 		if (empty($canNonMemberOrder)){			// 会員のみ注文が可能なとき
 			// ログインが必要な処理の場合は、ログイン状況をチェックする
 			switch ($task){
-				case 'order';			// 注文開始
-				case 'regcustomer';			// 購入者情報入力
-				case 'delivery';		// 配送先入力
-				case 'delivmethod';		// 配送方法選択
-				case 'payment';			// 支払い
-				case 'confirm';			// 確認
-				case 'complete';		// 手続き完了
-				case 'member';			// 会員情報変更
-				case 'changepwd';			// パスワード変更
-				case 'orderhistory';			// 注文履歴
+				case 'order':			// 注文開始
+				case 'regcustomer':			// 購入者情報入力
+				case 'delivery':		// 配送先入力
+				case 'delivmethod':		// 配送方法選択
+				case 'payment':			// 支払い
+				case 'confirm':			// 確認
+				case 'complete':		// 手続き完了
+				case 'member':			// 会員情報変更
+				case 'changepwd':			// パスワード変更
+				case 'orderhistory':			// 注文履歴
 					// ログイン状態を取得
 					if (!$this->gEnv->isCurrentUserLogined()){		// ログインされていない場合
 						$this->SetMsg(0, "ログインが必要です");
@@ -72,9 +74,9 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 		} else {
 			// ログインが必要な処理の場合は、ログイン状況をチェックする
 			switch ($task){
-				case 'member';			// 会員情報変更
-				case 'changepwd';		// パスワード変更
-				case 'orderhistory';	// 注文履歴
+				case 'member':			// 会員情報変更
+				case 'changepwd':		// パスワード変更
+				case 'orderhistory':	// 注文履歴
 					// ログイン状態を取得
 					if (!$this->gEnv->isCurrentUserLogined()){		// ログインされていない場合
 						$this->SetMsg(0, "ログインが必要です");
@@ -105,21 +107,21 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 		
 		// ##### コンテナを起動 #####
 		switch ($task){
-			case 'product':			// 商品表示機能
-			case 'cart';			// カート機能
-			case 'login';			// 会員ログイン
-			case 'regmember';			// 会員登録
-			case 'regcustomer';			// 購入者情報入力
-			case 'delivery';		// 配送
-			case 'delivmethod';		// 配送方法選択
-			case 'payment';			// 支払い
-			case 'confirm';			// 確認
-			case 'complete';		// 手続き完了
-			case 'sendpwd';			// パスワード送信
-			case 'member';			// 会員情報変更
-			case 'agreemember';		// 会員規約表示
-			case 'changepwd';			// パスワード変更
-			case 'orderhistory';			// 注文履歴
+			//case 'product':			// 商品表示機能
+			case 'cart':			// カート機能
+			case 'login':			// 会員ログイン
+			case 'regmember':			// 会員登録
+			case 'regcustomer':			// 購入者情報入力
+			case 'delivery':		// 配送
+			case 'delivmethod':		// 配送方法選択
+			case 'payment':			// 支払い
+			case 'confirm':			// 確認
+			case 'complete':		// 手続き完了
+			case 'sendpwd':			// パスワード送信
+			case 'member':			// 会員情報変更
+			case 'agreemember':		// 会員規約表示
+			case 'changepwd':			// パスワード変更
+			case 'orderhistory':			// 注文履歴
 				$this->gLaunch->goSubWidget($task);
 				return false;
 			default:
@@ -143,16 +145,16 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 
 		// 要求画面によってテンプレートを変更
 		switch ($task){
-			case 'order';			// 注文開始
-			case 'regcustomer';			// 購入者情報入力
-			case 'delivery';		// 配送
-			case 'delivmethod';		// 配送方法選択
-			case 'payment';			// 支払い
-			case 'confirm';			// 確認
-			case 'complete';		// 手続き完了
-			case 'member';			// 会員情報変更
-			case 'changepwd';			// パスワード変更
-			case 'orderhistory';			// 注文履歴
+			case 'order':			// 注文開始
+			case 'regcustomer':			// 購入者情報入力
+			case 'delivery':		// 配送
+			case 'delivmethod':		// 配送方法選択
+			case 'payment':			// 支払い
+			case 'confirm':			// 確認
+			case 'complete':		// 手続き完了
+			case 'member':			// 会員情報変更
+			case 'changepwd':			// パスワード変更
+			case 'orderhistory':			// 注文履歴
 				// ログインが必要であるメッセージを表示
 				return 'message_login.tmpl.html';
 			default:
@@ -174,18 +176,18 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 
 		// 要求画面によってテンプレートを変更
 		switch ($task){
-			case 'order';			// 注文開始
-			case 'regcustomer';			// 購入者情報入力
-			case 'delivery';		// 配送
-			case 'delivmethod';		// 配送方法選択
-			case 'payment';			// 支払い
-			case 'confirm';			// 確認
-			case 'complete';		// 手続き完了
-			case 'member';			// 会員情報変更
-			case 'changepwd';			// パスワード変更
-			case 'orderhistory';			// 注文履歴
+			case 'order':			// 注文開始
+			case 'regcustomer':			// 購入者情報入力
+			case 'delivery':		// 配送
+			case 'delivmethod':		// 配送方法選択
+			case 'payment':			// 支払い
+			case 'confirm':			// 確認
+			case 'complete':		// 手続き完了
+			case 'member':			// 会員情報変更
+			case 'changepwd':			// パスワード変更
+			case 'orderhistory':			// 注文履歴
 				// ログインが必要であるメッセージを表示
-				$this->tmpl->addVar("_widget", "login_url", $this->gEnv->createCurrentPageUrl() . '&task=login');		// ログイン用URL
+				$this->tmpl->addVar("_widget", "login_url", $this->getUrl($this->gEnv->createCurrentPageUrl() . '&task=login', true));		// ログイン用URL
 			default:
 		}
 	}
