@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: update_content_boxWidgetContainer.php 1432 2009-01-12 10:26:59Z fishbone $
+ * @version    SVN: $Id: update_content_boxWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -22,9 +22,9 @@ class update_content_boxWidgetContainer extends BaseWidgetContainer
 	private $itemCount;					// リスト項目数
 	private $isExistsList;				// リスト項目が存在するかどうか
 	const DEFAULT_ITEM_COUNT = 10;		// デフォルトの表示項目数
-	const DEFAULT_TITLE = '更新コンテンツ';
 	const CONTENT_TYPE = '';		// コンテンツタイプ
 	const TARGET_WIDGET = 'default_content';		// 呼び出しウィジェットID
+	const DEFAULT_TITLE = '更新コンテンツ';			// デフォルトのウィジェットタイトル
 	
 	/**
 	 * コンストラクタ
@@ -65,11 +65,9 @@ class update_content_boxWidgetContainer extends BaseWidgetContainer
 		$langId = $this->gEnv->getDefaultLanguage();
 		
 		$this->itemCount = self::DEFAULT_ITEM_COUNT;	// 表示項目数
-		$title = self::DEFAULT_TITLE;
 		$paramObj = $this->getWidgetParamObj();
 		if (!empty($paramObj)){
 			$this->itemCount	= $paramObj->itemCount;
-			$title		= $paramObj->name;
 		}
 			
 		// ログインユーザでないときは、ユーザ制限のない項目だけ表示
@@ -80,9 +78,18 @@ class update_content_boxWidgetContainer extends BaseWidgetContainer
 		$this->db->getContentList($langId, self::CONTENT_TYPE, $all, array($this, 'itemsLoop'));
 				
 		// 画面にデータを埋め込む
-		if (!empty($title)) $this->tmpl->addVar("_widget", "title",	'<tr><th>' . $title . '</th></tr>');
-		$this->tmpl->addVar("_widget", "default_menu_param", $this->gDesign->getDefaultWidgetTableParam());
-		if ($this->isExistsList) $this->tmpl->setAttribute('linklist', 'visibility', 'visible');
+		if ($this->isExistsList) $this->tmpl->setAttribute('itemlist', 'visibility', 'visible');
+	}
+	/**
+	 * ウィジェットのタイトルを設定
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
+	 * @return string 						ウィジェットのタイトル名
+	 */
+	function _setTitle($request, &$param)
+	{
+		return self::DEFAULT_TITLE;
 	}
 	/**
 	 * 取得したメニュー項目をテンプレートに設定する
@@ -99,20 +106,22 @@ class update_content_boxWidgetContainer extends BaseWidgetContainer
 		
 		$serial = $fetchedRow['vc_serial'];
 		$totalViewCount = $fetchedRow['total'];
-		$name = $this->convertToDispString($fetchedRow['cn_name']);
+		$name = $fetchedRow['cn_name'];
 
 		// リンク先の作成
-		$url = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'contentid=' . $fetchedRow['cn_id']);// コンテンツ表示ウィジェットへのリンク
-		$link = '<a href="' . $this->convertUrlToHtmlEntity($url) . '">' . $name . '</a>';
+		$linkUrl = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'contentid=' . $fetchedRow['cn_id']);// コンテンツ表示ウィジェットへのリンク
 
-		$row = array(
-			'total' => $totalViewCount,		// 閲覧数
-			'link' => $link		// リンク
-		);
-		$this->tmpl->addVars('linklist', $row);
-		$this->tmpl->parseTemplate('linklist', 'a');
+		if (!empty($name)){
+			$row = array(
+				'total' => $totalViewCount,		// 閲覧数
+				'link_url' => $this->convertUrlToHtmlEntity($this->getUrl($linkUrl, true)),		// リンク
+				'name' => $this->convertToDispString($name)			// タイトル
+			);
+			$this->tmpl->addVars('itemlist', $row);
+			$this->tmpl->parseTemplate('itemlist', 'a');
 		
-		$this->isExistsList = true;		// リスト項目が存在するかどうか
+			$this->isExistsList = true;		// リスト項目が存在するかどうか
+		}
 		return true;
 	}
 }
